API Overview
=============

This is a listing of the important and most used for an exhaustive
(and potentially exhausting) listing see the module index:

   
Boundary Conditions & Positioning
---------------------------------

* :any:`Box Vector Conversions <../api/geomm.box_vectors>`
* :any:`Apply & Move Periodic Boundary Conditions <../api/geomm.centering>`
* :any:`Group Molecules in same PBC image <../api/geomm.grouping>`



RMSD & Superimposition
----------------------

* :any:`RMSD <../api/geomm.rmsd>`
* :any:`Superimpose <../api/geomm.superimpose>`

Thermodynamics & Kinetics
-------------------------

* :any:`Transition State Observables <../api/geomm.arrhenius>`
* :any:`Kinetic Energy <../api/geomm.kinetic_energy>`
